@@ -1129,6 +1129,18 @@ latin1_to_utf8 (const char *latin1)
 
 char*
 _wnck_get_res_class_utf8 (Window xwindow)
+{
+  char *res_class;
+
+  _wnck_get_wmclass (xwindow, &res_class, NULL);
+
+  return res_class;
+}
+
+void
+_wnck_get_wmclass (Window xwindow,
+                   char **res_class,
+                   char **res_name)
 {
   XClassHint ch;
   char *retval;
@@ -1144,19 +1156,28 @@ _wnck_get_res_class_utf8 (Window xwindow)
   _wnck_error_trap_pop ();
   
   retval = NULL;
+
+  if (res_class)
+    *res_class = NULL;
+
+  if (res_name)
+    *res_name = NULL;
   
   if (ch.res_name)
     {
+      if (res_name)
+        *res_name = latin1_to_utf8 (ch.res_name);
+      
       XFree (ch.res_name);
     }
 
   if (ch.res_class)
     {
-      retval = latin1_to_utf8 (ch.res_class);
+      if (res_class)
+        *res_class = latin1_to_utf8 (ch.res_class);
+      
       XFree (ch.res_class);
     }
-
-  return retval;
 }
 
 void
@@ -2140,15 +2161,17 @@ _wnck_get_fallback_icons (GdkPixbuf **iconp,
                           int         ideal_mini_width,
                           int         ideal_mini_height)
 {
-  *iconp = default_icon_at_size (ideal_width > 0 ? ideal_width :
-                                 DEFAULT_ICON_WIDTH,
-                                 ideal_height > 0 ? ideal_height :
-                                 DEFAULT_ICON_HEIGHT);
+  if (iconp)
+    *iconp = default_icon_at_size (ideal_width > 0 ? ideal_width :
+                                   DEFAULT_ICON_WIDTH,
+                                   ideal_height > 0 ? ideal_height :
+                                   DEFAULT_ICON_HEIGHT);
 
-  *mini_iconp = default_icon_at_size (ideal_mini_width > 0 ? ideal_mini_width :
-                                      DEFAULT_MINI_ICON_WIDTH,
-                                      ideal_mini_height > 0 ? ideal_mini_height :
-                                      DEFAULT_MINI_ICON_HEIGHT);
+  if (mini_iconp)
+    *mini_iconp = default_icon_at_size (ideal_mini_width > 0 ? ideal_mini_width :
+                                        DEFAULT_MINI_ICON_WIDTH,
+                                        ideal_mini_height > 0 ? ideal_mini_height :
+                                        DEFAULT_MINI_ICON_HEIGHT);
 }
 
 
@@ -2288,7 +2311,7 @@ _wnck_set_desktop_layout (Screen *xscreen,
                    RootWindowOfScreen (xscreen),
 		   _wnck_atom_get ("_NET_DESKTOP_LAYOUT"),
 		   XA_CARDINAL, 32, PropModeReplace,
-		   (guchar *)&data, sizeof (data));
+		   (guchar *)&data, sizeof (data) / 4);
 
   _wnck_error_trap_pop ();
 }
